# nr.utils.re

This module provides some utility functions for applying regular expressions.

<!--- API Documentation BEGIN -->

<!--- API Documentation END -->

---

<p align="center">Copyright &copy; 2020 Niklas Rosenstein</p>
